summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndreas Enge <andreas@enge.fr>2025-09-21 21:41:09 +0200
committerAndreas Enge <andreas@enge.fr>2025-09-21 21:49:36 +0200
commitc0e31bbb7cbfa40c11f748f4540a4c9f3e3f01ac (patch)
treeaa8851b76294f97f17c471c775ba83693e8a6d29
parent24701a21e812acdbb9cad67d0af390528b572bdc (diff)
gnu: gnubg: Update to 1.08.003.
* gnu/packages/games.scm (gnubg): Update to 1.08.003. [native-inputs]: Add flex. Replace python-2 by python. Remove libxcrypt. Change-Id: I1093f481ad664b4183b09c238d220fd36009ca4d
-rw-r--r--gnu/packages/games.scm14
1 files changed, 7 insertions, 7 deletions
diff --git a/gnu/packages/games.scm b/gnu/packages/games.scm
index 7ce77ff80f0..98ebefc19e7 100644
--- a/gnu/packages/games.scm
+++ b/gnu/packages/games.scm
@@ -2395,7 +2395,7 @@ such as chess or stockfish.")
(define-public gnubg
(package
(name "gnubg")
- (version "1.07.001")
+ (version "1.08.003")
(source
(origin
(method url-fetch)
@@ -2403,10 +2403,10 @@ such as chess or stockfish.")
version "-sources.tar.gz"))
(sha256
(base32
- "07l2srlm05c99l4pppba8l54bnh000ns2rih5h8rzbcw84lrffbj"))))
+ "0yar8j6g2f1q9zz9m9ha9xzvjr6mwp2qrzwhp9ppizyg2fdrczbg"))))
(build-system gnu-build-system)
(inputs (list ;; XXX: Build with an older Pango for 'pango_font_get_hb_font' and
;; 'pango_coverage_get_type'. Try removing this for versions > 1.07.001.
pango-1.42
glib
readline
@@ -2415,10 +2415,10 @@ such as chess or stockfish.")
glu
gtkglext
sqlite
- libcanberra
- libxcrypt)) ;required by Python.h
- (native-inputs `(("python-2" ,python-2)
- ("pkg-config" ,pkg-config)))
+ libcanberra))
+ (native-inputs (list flex
+ python
+ pkg-config))
(arguments
`(#:configure-flags
;; SSE instructions are available on Intel systems only.
@@ -2403,10 +2403,10 @@ such as chess or stockfish.")
(build-system gnu-build-system)
(inputs (list ;; XXX: Build with an older Pango for 'pango_font_get_hb_font' and
- ;; 'pango_coverage_get_type'. Try removing this for versions > 1.07.001.
+ ;; 'pango_coverage_get_type'. Try removing this for versions > 1.08.003.
pango-1.42
glib